classdef Antenna < handle
%% CLASS Antenna, a subclass of the handle class
%
% A class to model antenna objects using a theoretical pattern based on
% that given in 3GPP 36.814 Annex A Table A.2.1.1-2 
%

% Martin Fenton - Version 1.0 05/04/2011

%% Properties of the Antenna class  

    properties

        H3dB = 68;                  % The horizontal 3 dB beamwidth (degrees)
        V3dB = 10.5;                % The vertical 3 dB beamwidth (degrees)
        BoreSightGain = 15.5;       % The boresight gain (dBi)

    end
    
%% Methods of the Antenna class

    methods
        
%% Antenna - the constructor method

        function Ant = Antenna(BoreSightGain, H3dB, V3dB) %, RefFreq)

            if nargin > 0
                Ant.BoreSightGain = BoreSightGain;
                Ant.H3dB = H3dB;
                Ant.V3dB = V3dB;
            end
        end
        
%% Pattern - returns the antenna gain from the antenna at a specific azimuth
% and elevation in relation to the antenna boresight direction

        function gain = Pattern(Ant, Azimuth, Elevation, downtilt)
           
            AH = -min(12*(Azimuth/Ant.H3dB)^2, 25);
            AV = -min(12*((Elevation-downtilt)/Ant.V3dB)^2, 20);
            gain = Ant.BoreSightGain-min(-(AH+AV),25);
        end
        
    end
    
end

