function BSArray = BaseStationArray(siteList, Downtilt) 
%% FUNCTION BSArray = BaseStationArray(siteList, Downtilt)
%
% Function to set up an array of base stations (objects of the Station
% class)
% 
% Input:
%   siteList = A matrix of site locations
%   Downtilt = Antenna downtilt (degrees)
%
% Output:
%   BSArray  = A matrix of Station objects (representing base stations)
%

% Martin Fenton - Version 1.0 11/04/2011

%% Check if downtilt argument is supplied, if not use default

    if nargin == 1
        Downtilt = 3;
    end
    
%% Set up the base station array
    for i = 1:size(siteList,1)
        switch size(siteList,2)
            case 4
                Power = [siteList(i,4) siteList(i,4) siteList(i,4)];
            case 5
                Power = [siteList(i,4) siteList(i,5) siteList(i,5)];
            case 6
                Power = [siteList(i,4) siteList(i,5) siteList(i,6)];
        end
        BaseStation(i) = Station([siteList(i,1) siteList(i,2)],'BS',siteList(i,3),Power);
        BaseStation(i).Downtilt = Downtilt; 

    end
    BSArray = BaseStation;
%    plotBaseStationArray(BSArray);
end

function plotBaseStationArray(BSArray)

    for i = 1:length(BSArray)
        x(i)= BSArray(i).Coords(1);
        y(i)= BSArray(i).Coords(2);
    end
    plot(x ,y, 'bo');
    axis equal
end