function DowntiltSet( BSArray, ISDfact, V3dBfact )
%% FUNCTION DowntiltSet( BSArray, ISDfact, V3dBfact )
%
% Function to calculate the downtilt of each base station antenna based on the distance to the nearest
% surrounding 6 sites the height of the site and the antennas vertical beamwidth
% 
% Input:
%   BSArray  = An array of basestation objects (objects of the Station class)
%   ISDfact  = factor to adjust downtilt depenent on inter-site distance (ISD)
%   V3dBfact = factor to adjust downtilt dependent on the antenna vertical 3dB beamwidth
%
% Output:
%   Sets the Downtilt property of the BSArray objects
%

% Martin Fenton - Version 1.0 21/10/2011

    z = size(BSArray,2);

    parfor m = 1:z
        dist = Distance(BSArray(m), BSArray);
        dist = sort(dist);
        ISD = sum(dist(1:7))/6;
        Downtilt(m) = atand((BSArray(m).Height)/(ISDfact*ISD)) + BSArray(m).Ant.V3dB/V3dBfact;
    end
    for m = 1:z
        BSArray(m).Downtilt = Downtilt(m);
    end

end

