classdef PixelMap < handle
%% CLASS PixelMap, a subclass of the handle class
%
% Class to model an array of pixel points covering the area defined from an 
% existing clutter map and assigning vectors of shadow fading and
% building penetration values for each pixel for an bases station array of
% an assumed size (e.g. 20 base stations)
%

% Martin Fenton Version 2.0 21/10/2011

%% Properties of the PixelMap class

    properties
        Dist = 50;
        Pixels = Pixel;
    end
    
%% Methods of the PixelMap class

    methods
        
%% PixelMap - the constructor method

        function Map = PixelMap(BSData, ClutterData, Rows, Columns, Seed)
        % BSData is the number of base stations to generate shadow fading
        % and BPL data for. ClutterData is an array of data whose columns
        % represent Eastings, Northings, clutter value and population for
        % each 'Pixel' of the PixelMap
        
            if nargin <= 4
                Seed = 10247;
            end
        
            TmpClutter = 4;
            z = BSData;
                          
            steps_x = Columns;
            steps_y = Rows;
           
            k = steps_x * steps_y;
%            rng(10247); % Seed the random number generator - same set of random variables are generated for each run
            rng(Seed); % Seed the random number generator - same set of random variables are generated for each run

            LocalSFValue = randn(k,1); % Normal distribution
            LocalBPValue = randn(k,1); % Normal distribution
            LocalBPDepth = rand(k,1);
            
            k = steps_x * steps_y * z;
            BaseSFValues = randn(k,1); % Normal distribution
            BaseBPValues = randn(k,1); % Normal distribution
            
            Pixs(steps_y, steps_x) = Pixel([0 0], TmpClutter, z);

            k = 0;
            for m = 1:steps_y % Row - ie Northing

%                waitbar(m / steps_y);

                for n = 1:steps_x; % Column - ie Easting
                   
                    k = k + 1;
                    Pixs(m,n).LocalSFValue = LocalSFValue(k);
                    Pixs(m,n).LocalBPValue = LocalBPValue(k);
                    Pixs(m,n).LocalBPDepth = LocalBPDepth(k);
                    Pixs(m,n).BaseSFValues = BaseSFValues((k*z-z+1):(k*z));
                    Pixs(m,n).BaseBPValues = BaseBPValues((k*z-z+1):(k*z));
                    Pixs(m,n).Clutter = ClutterData(k,3);
                    Pixs(m,n).Population = ClutterData(k,4);
                    Pixs(m,n).Coords = [ClutterData(k,1) ClutterData(k,2)];

                end
            end
            
            Map.Dist = 50;
            Map.Pixels = Pixs;
        end
        
    end

end

