classdef Point < handle
%% CLASS Point, a subclass of the handle class
%
% Class defining a base class for all point like objects (i.e. locations) 
%

% Martin Fenton - Version 1.0 05/04/2011

%% Properties of the Point class  

    properties

        Coords = [0 0]; % Coodinate of the point (Easting, Northing)

    end
    
%% Methods of the Point class

    methods

%% Point - the constructor method

        function P = Point(Coords)

            if nargin > 0
                P.Coords = Coords;
            else
                P.Coords = [0 0];
            end
        end

%% Dist - returns the horizontal distance between points
        
        function Dist = Distance(P_A, P_B)
        % Horizontal distance between point P_A and vector of points P_B

            z = length(P_B);
            Dist = zeros(z,1);
            for i = 1:z
                Dist(i) = sqrt((P_A.Coords(1)-P_B(i).Coords(1))^2 +...
                    (P_A.Coords(2)-P_B(i).Coords(2))^2);
            end
        end
        
%% Dist - returns the direction (in degrees) between points

        function Dir = Direction(P_A, P_B) 
        % Direction in degrees between point P_A and vector of points P_B 
        % (increasing anticlockwise from due east (zero degrees)

            z = length(P_B);
            Dir = zeros(z,1);
            for i = 1:z
                Dir(i) = 180 * atan2((P_B(i).Coords(2)-P_A.Coords(2)) ,...
                    (P_B(i).Coords(1)-P_A.Coords(1))) / pi;
            end
        end
        
    end

end

