%% SCRIPT exportCapacityMultiFreq2Excel
%
% Script to generate and export mult-frequency capacity data to Excel workbook 
%

% Martin Fenton - Version 1.0 09/01/12

%% The following data is normally stored in the TP.mat file
% sampleAres = 'WestLondon';
% Depths = ['00'; '01'; '05'; '10'; '15']; % BP depth in metres, '00' equals outdoors
% Frequency = [800, 1800, 2600];
% networkLoading = [0.15, 0.25, 0.35, 0.50, 0.65, 0.85];
% SINR_min = [-10, -5]; % SINR cut-off in dB
% tpMapping = ['1xMAP36.942(SINR-0dB)'; '1xMAP36.942(SINR-0dB)']; % ['2xMAP36.942(SINR-3dB)'; '1xMAP36.942(SINR-0dB)'];
% BPRising = [-1, 2]; % Best and worst case BPL dependancy with frequency

tic;

h = waitbar(0,'Please wait, exporting coverage data to Excel...');

s = struct('LoadingOwnCell', 0.85,...
           'MIMO', 2,...
           'Mapping', '1xMAP36.942(SINR-0dB)',...
           'gBitRate', 2,...
           'FSPS', 'FSPS',...
           'SINR_min', -5);
       
pop = 8437101;
networkSize = ['12000'; '18000']; % ['04000'; '08000'; '12000'; '16000'; '20000']; % ['08000'; '12000']; Subset of networkSizes
sites = [1740, 2651];
gBitRate = [2, 5];
SINR_min = [-10, -5];
BPRising = [-1, 2];

scenariosB = [10, 20;...
              15, 20;...
              20, 20;...
              10, 20;...
              15, 20;...
              20, 20];
              
scenariosF = [800, 2600;...
              800, 2600;...
              800, 2600;...
              1800, 2600;...
              1800, 2600;...
              1800, 2600];
              
sampleArea = 'WestLondon';

%% Create the timestamp based on the current date and time
timeStamp = datestr(now,30);

%% Create a results folder with datestamp equal to the current date
resultsFolderName = ['./Results/', timeStamp(1:8)];
[~,~,~] = mkdir(resultsFolderName);

Workbook = [resultsFolderName, '/Capacity_multifreq_results_', sampleArea, '_', timeStamp(1:8), '.xlsx'];
copyfile('./Results/Capacity_multifreq_results_template.xlsx', Workbook);

z = length(gBitRate)*size(scenariosB,1)*size(networkSize,1)*2; % 540; % Number of data rows in worksheets
rowIdentifier = cell(z,8);
rowIdentifier{z,8} = [];
outputArrayP = zeros(z,41);
outputArrayL = zeros(z,41);

%% Iterate through parameters calculate throughputs and store in Excel

Row = 1;

for j = 1:length(gBitRate)
    s.gBitRate = gBitRate(j);
    TP = [int2str(gBitRate(j)), 'Mbps'];
    for k = 1:size(scenariosB,1)
        f1 = scenariosF(k,1);
        if f1 < 1000
            Freq1 = ['0', int2str(f1), 'MHz'];
        else
            Freq1 = [int2str(f1), 'MHz'];
        end
        f2 = scenariosF(k,2);
        if f2 < 1000
            Freq2 = ['0', int2str(f2), 'MHz'];
        else
            Freq2 = [int2str(f2), 'MHz'];
        end
        bw1 = scenariosB(k,1);
        if bw1 < 10
            BW1 = ['0', int2str(bw1), 'MHz'];
        else
            BW1 = [int2str(bw1), 'MHz'];
        end
        bw2 = scenariosB(k,2);
        if bw2 < 10
            BW2 = ['0', int2str(bw2), 'MHz'];
        else
            BW2 = [int2str(bw2), 'MHz'];
        end
        for i = 1:size(networkSize,1)
            Sites = sites(i);
            for x = 1:2 % Min var, max var
                
                waitbar(Row / z, h)

                s.SINR_min = SINR_min(x);
                
                if BPRising(x) == -1   
                    outputName = 'MZ';
                else
                    outputName = ['M', int2str(BPRising(x))];
                end
                
                if x == 1
                    variation = 'Min var';
                else
                    variation = 'Max var';
                end
                
                P = ['P_', outputName, '_', networkSize(i,:), '_', Freq1, BW1, '_', Freq2, BW2, '_', int2str(gBitRate(j)), 'Mbps'];
                L = ['L_', outputName, '_', networkSize(i,:), '_', Freq1, BW1, '_', Freq2, BW2, '_', int2str(gBitRate(j)), 'Mbps'];
                tempSINR = ['SINR_', outputName, '_', networkSize(i,:)];

                eval(['[', P, ',', L, '] = ParCapacityMultiFrequency(', tempSINR, ',[f1, f2], [bw1, bw2], s, Sites, pop);']);

                rowIdentifier(Row,:) = {TP, [int2str(f1), 'MHz'], [int2str(bw1), 'MHz'], [], [], networkSize(i,:), variation, ['P', int2str(f1)]};
                rowIdentifier(Row+1,:) = {TP, [], [], [int2str(f2), 'MHz'], [int2str(bw2), 'MHz'], [], [], ['P', int2str(f2)]};
                
                outputArrayP(Row,:) = eval([P, '(1,:)']);
                outputArrayP(Row+1,:) = eval([P, '(2,:)']);
                outputArrayL(Row,:) = eval([L, '(1,:)']);
                outputArrayL(Row+1,:) = eval([L, '(2,:)']);

                Row = Row + 2; % Incrument to the next row
            end
        end
    end
end

[~,~] = xlswrite(Workbook,rowIdentifier,'Ppercent','B14');
[~,~] = xlswrite(Workbook,outputArrayP,'Ppercent','J14');
[~,~] = xlswrite(Workbook,rowIdentifier,'Loading','B14');
[~,~] = xlswrite(Workbook,outputArrayL,'Loading','J14');

close(h);

toc;