%% SCRIPT exportCapacitySingleFreq2Excel
%
% Script to export single-frequency capacity data to Excel workbook 
%

% Martin Fenton - Version 1.0 09/01/12

%% The following data is normally stored in the TP.mat file
% sampleAres = 'WestLondon';
% Depths = ['00'; '01'; '05'; '10'; '15']; % BP depth in metres, '00' equals outdoors
% Frequency = [800, 1800, 2600];
% networkLoading = [0.15, 0.25, 0.35, 0.50, 0.65, 0.85];
% SINR_min = [-10, -5]; % SINR cut-off in dB
% tpMapping = ['1xMAP36.942(SINR-0dB)'; '1xMAP36.942(SINR-0dB)']; % ['2xMAP36.942(SINR-3dB)'; '1xMAP36.942(SINR-0dB)'];
% BPRising = [-1, 2]; % Best and worst case BPL dependancy with frequency

tic;

h = waitbar(0,'Please wait, exporting coverage data to Excel...');

networkSize = ['04000'; '06000'; '08000'; '10000'; '12000'; '14000'; '16000'; '18000'; '20000']; % networkSizes;
bandwidth = ['05'; '10'; '15'; '20']; % '25'; '30'; '35'; '40'];
gBitRate = [2, 5];
BPRising = [-1, 2];
Frequency = [800, 1800, 2600];
sampleAres = 'WestLondon';

%% Create the timestamp based on the current date and time
timeStamp = datestr(now,30);

%% Create a results folder with datestamp equal to the current date
resultsFolderName = ['./Results/', timeStamp(1:8)];
[~,~,~] = mkdir(resultsFolderName);

Workbook = [resultsFolderName, '/Capacity_singlefreq_results_', sampleArea, '_', timeStamp(1:8), '.xlsx'];
copyfile('./Results/Capacity_singlefreq_results_template.xlsx', Workbook);

z = length(gBitRate)*size(networkSize,1)*length(Frequency)*size(bandwidth,1)*2;
rowIdentifier = cell(z,5);
rowIdentifier{z,5} = [];
outputArrayP = zeros(z,41);
outputArrayL = zeros(z,41);

%% Iterate through parameters calculate throughputs and store in Excel

Row = 1;

for j = 1:length(gBitRate)
    TP = [int2str(gBitRate(j)), 'Mbps'];
    for k = 1:length(Frequency)
        freq = [int2str(Frequency(k)), 'MHz'];
        for m = 1:size(bandwidth,1)
            BW = [int2str(str2num(bandwidth(m,:))), 'MHz'];
            for i = 1:size(networkSize,1)
                for x = 1:2 % Min var, max var

                    waitbar(Row / z, h)
                    if BPRising(x) == -1   
                        outputName = 'MZ';
                    else
                        outputName = ['M', int2str(BPRising(x))];
                    end
                    if x == 1
                        variation = 'Min var';
                    else
                        variation = 'Max var';
                    end
                    
                    rowIdentifier(Row,:) = {TP, freq, BW, networkSize(i,:), variation};
    
%                    if strcmp(networkSize(i,:),'08000') || strcmp(networkSize(i,:),'12000') || strcmp(networkSize(i,:),'16000')
                        outputArrayP(Row,:) = eval(['P_', outputName, '_', networkSize(i,:), '_', bandwidth(m,:), 'MHz_', int2str(gBitRate(j)), 'Mbps(', int2str(k), ',:);']);
                        outputArrayL(Row,:) = eval(['L_', outputName, '_', networkSize(i,:), '_', bandwidth(m,:), 'MHz_', int2str(gBitRate(j)), 'Mbps(', int2str(k), ',:);']);
%                    end
                    
                    Row = Row + 1; % Incrument to the next row
                end
            end
        end
    end
end

[~,~] = xlswrite(Workbook,rowIdentifier,'Ppercent','B14');
[~,~] = xlswrite(Workbook,outputArrayP,'Ppercent','G14');
[~,~] = xlswrite(Workbook,rowIdentifier,'Loading','B14');
[~,~] = xlswrite(Workbook,outputArrayL,'Loading','G14');

close(h);

toc;