%% SCRIPT exportThroughput2Excel
%
% Script to export throughput and coverage data to Excel workbook 
%

% Martin Fenton - Version 1.0 02/12/11

%% The following data is normally stored in the TP.mat file
% sampleAres = 'WestLondon';
% Depths = ['00'; '01'; '05'; '10'; '15']; % BP depth in metres, '00' equals outdoors
% Frequency = [800, 1800, 2600];
% networkLoading = [0.15, 0.25, 0.35, 0.50, 0.65, 0.85];
% SINR_min = [-10, -5]; % SINR cut-off in dB
% tpMapping = ['1xMAP36.942(SINR-0dB)'; '1xMAP36.942(SINR-0dB)']; % ['2xMAP36.942(SINR-3dB)'; '1xMAP36.942(SINR-0dB)'];
% BPRising = [-1, 2]; % Best and worst case BPL dependancy with frequency

tic;

h = waitbar(0,'Please wait, exporting throughput data to Excel...');

networkSize = ['04000'; '08000'; '12000'; '16000'; '20000']; % ['08000'; '12000']; Subset of networkSizes
bandwidth = ['05'; '10'; '15'; '20']; % Carrier bandwidths in MHz


%% Create the timestamp based on the current date and time
timeStamp = datestr(now,30);

%% Create a results folder with datestamp equal to the current date
resultsFolderName = ['./Results/', timeStamp(1:8)];
[~,~,~] = mkdir(resultsFolderName);

Workbook = [resultsFolderName, '/Summary_technical_results_', sampleArea, '_', timeStamp(1:8), '.xlsx'];
copyfile('./Results/Summary_technical_results_template.xlsx', Workbook);

z = size(networkSize,1)*size(Depths,1)*length(Frequency)*size(bandwidth,1)*length(networkLoading)*2;
rowIdentifier = cell(z,6);
rowIdentifier{z,6} = [];
cutOffdata = zeros(z,2);
outputArray = zeros(z,20);

%% Set up structure containing throughput controls for throughput calculations and speed graphs
sp = struct('LoadingOwnCell', mc2.LoadingOwnCell,...
            'SINR_min', SINR_min(1),...
            'MIMO', mc2.MIMOMode,...
            'Mapping', tpMapping(1,:),...
            'gBitRate', 0.000);

%% Iterate through parameters calculate throughputs and store in Excel

Worksheet = 'Throughput';
xData = 5:5:100;
Row = 1;

for i = 1:size(networkSize,1)
    for j = 1:size(Depths,1)
        if strcmp(Depths(j,:), '00')
            depth = 'Outdoors';
        else
            depth = [int2str(str2num(Depths(j,:))), 'm'];
        end
        for k = 1:length(Frequency)
            freq = [int2str(Frequency(k)), 'MHz'];
            for m = 1:size(bandwidth,1)
                BW = [int2str(str2num(bandwidth(m,:))), 'MHz'];
                for n = 1:length(networkLoading)
                    for x = 1:2

                        waitbar(Row / z, h)
                        sp.Mapping = tpMapping(x,:);
                        sp.SINR_min = SINR_min(x);
                        if BPRising(x) == -1   
                            outputName = [Depths(j,:), 'MZ'];
                        else
                            outputName = [Depths(j,:), 'M', int2str(BPRising(x))];
                        end
                        if x == 1
                            variation = 'Min var';
                        else
                            variation = 'Max var';
                        end
                        
                        rowIdentifier(Row,:) = {networkSize(i,:), depth, freq, BW, networkLoading(n), variation};
                        tempTP = eval(['SINR2TP(SINR_', outputName, '_', networkSize(i,:), ', ', bandwidth(m,:),', sp);']);
                        
                        [~, Index] = min(tempTP(:,3*(k-1)+1,n));
                        tempCov = tempTP(Index-1,3*(k-1)+2,n);
                        tempTPCov = tempTP(Index-1,3*(k-1)+1,n);
                        cutOffdata(Row,:) = [tempCov,tempTPCov];

                        outputArray(Row,:) = interp1(tempTP(:,3*(k-1)+2,n),tempTP(:,3*(k-1)+1,n),xData,'nearest','extrap');
                        Row = Row + 1; % Incrument to the next row
                    end
                end
            end
        end
    end
end

[~,~] = xlswrite(Workbook,rowIdentifier,Worksheet,'B15');
[~,~] = xlswrite(Workbook,cutOffdata,Worksheet,'H15');
[~,~] = xlswrite(Workbook,outputArray,Worksheet,'J15');

%% Iterate through parameters calculate coverage and store in Excel

networkSize = networkSizes;
Worksheet = 'Coverage';

z = size(Depths,1)*length(Frequency)*size(bandwidth,1)*length(networkLoading)*2;
rowIdentifier = cell(z,6);
rowIdentifier{z,6} = [];
outputArray = zeros(z,size(networkSize,1));

Row = 1;
sp.gBitRate = 5;
waitbar(0, h, 'Please wait, exporting coverage data to Excel...')

for j = 1:size(Depths,1)
    if strcmp(Depths(j,:), '00')
        depth = 'Outdoors';
    else
        depth = [int2str(str2num(Depths(j,:))), 'm'];
    end
    for k = 1:length(Frequency)
        freq = [int2str(Frequency(k)), 'MHz'];
        for m = 1:size(bandwidth,1)
            BW = [int2str(str2num(bandwidth(m,:))), 'MHz'];
            for n = 1:length(networkLoading)
                for x = 1:2

                    waitbar(Row / z, h)
                    sp.Mapping = tpMapping(x,:);
                    sp.SINR_min = SINR_min(x);
                    if BPRising(x) == -1   
                        outputName = [Depths(j,:), 'MZ'];
                    else
                        outputName = [Depths(j,:), 'M', int2str(BPRising(x))];
                    end
                    if x == 1
                        variation = 'Min var';
                    else
                        variation = 'Max var';
                    end

                    rowIdentifier(Row,:) = {'5Mbps', depth, freq, BW, networkLoading(n), variation};
                    for i = 1:size(networkSize,1)
                        tempTP = eval(['SINR2TP(SINR_', outputName, '_', networkSize(i,:), ', ', bandwidth(m,:),', sp);']);

                        [~, Index] = min(tempTP(:,3*(k-1)+1,n));
                        tempCov = tempTP(Index-1,3*(k-1)+2,n);
                        outputArray(Row,i) = tempCov;
                    end
                    Row = Row + 1; % Incrument to the next row
                end
            end
        end
    end
end

[~,~] = xlswrite(Workbook,rowIdentifier,Worksheet,'B15');
[~,~] = xlswrite(Workbook,outputArray,Worksheet,'H15');

close(h);

toc;