%% SCRIPT graphsCoverage
%
% Script to generate coverage graphs based on individual depths
%

% Martin Fenton - Version 1.0 02/12/11

% Ceck if timestamp exists, if not create timestampe from todays date and current time
if exist('timeStamp', 'var') == 0
    timeStamp = datestr(now,30);
end

% Create results folder
resultsFolderName = ['.\Results\', timeStamp(1:8), '\Coverage_', int2str(sp.gBitRate), 'Mbps'];
[~,~,~] = mkdir(resultsFolderName);

% Create plots
for y = 1:size(Depths, 1) % Loop through each BPL depth
    for k = 1:size(bandwidth,1)
        for j = 1:length(networkLoading)

            % Close all current figures
            close all;
            figureName = ['Coverage ', timeStamp];

            % Ensure root units are pixels and get the size of the screen
            set(0,'Units','pixels') 
            scnsize = get(0,'ScreenSize');

            % Create figure
            fig1 = figure('Name',figureName,...
                          'InvertHardcopy','off',...
                          'Color',[1 1 1]);

            % Set figure dimentions and centre on screen
            borders = get(fig1,'OuterPosition') - get(fig1,'Position');
            figWidth = 900;
            figHeight = 600;
            position = [scnsize(3)/2 + borders(1) - figWidth/2,...
                        scnsize(4)/2 + borders(2) - figHeight/2,...
                        figWidth + borders(3),...
                        figHeight + borders(4)];
            set(fig1,'OuterPosition',position);

            % Create axes
            axes1 = axes('Parent',fig1,...
                         'YGrid','on',...
                         'XTickLabel',{'','2,000','4,000','6,000','8,000','10,000','12,000','14,000','16,000','18,000','20,000'},...
                         'XTick',[0 2000 4000 6000 8000 10000 12000 14000 16000 18000 20000],...
                         'XGrid','on',...
                         'FontWeight','bold');
            % Uncomment the following line to preserve the X-limits of the axes
            xlim(axes1,[0 20000]);
            % Uncomment the following line to preserve the Y-limits of the axes
            ylim(axes1,[0 100]);
            % Uncomment the following line to preserve the Z-limits of the axes
            % zlim(axes1,[-1 1]);
            box(axes1,'on');
            hold(axes1,'all');

            % Create xlabel
            xlabel('Sites (equivalent national network)','FontWeight','bold');

            % Create ylabel
            ylabel('% Delivery addresses','FontWeight','bold');
                
            xData = str2num(networkSize);

            for m = 1:2     % 1 = best case, 2 = worst case

                if BPRising(m) == -1   
                    outputName = [Depths(y,:), 'MZ'];
                else
                    outputName = [Depths(y,:), 'M', int2str(BPRising(m))];
                end

                if m == 1
                    lineStyle = '-';
                    sName = 'Min var: ';
                else
                    lineStyle = '--';
                    sName = 'Max var: ';
                end

                for n = 1:length(Frequency)
                    switch n
                        case 1
                            lineColour = [1 0 0];
                        case 2
                            lineColour = [0 0 1];
                        case 3
                            lineColour = [0 0.5 0];
                        otherwise
                            lineColour = [0.5 0.5 0.5];
                    end

                    yData = eval(['Cov_', outputName, '_M', int2str(m), '_', bandwidth(k,:), 'MHz(:,',int2str(n),',',int2str(j),')']);
                    seriesName = [sName, int2str(Frequency(n)), ' MHz - ', int2str(100*networkLoading(j)), '% loaded'];
                    plot(xData,yData,...
                         'Parent',axes1,...
                         'LineWidth',2,...
                         'LineStyle',lineStyle,...
                         'Color',lineColour,...
                         'DisplayName',seriesName);
                end
            end
            
            fileName = ['Coverage-', sampleArea, '-', Depths(y,:), 'm-', int2str(sp.gBitRate), 'Mbps-L', int2str(100*networkLoading(j)), '-', bandwidth(k,:), 'MHz-', timeStamp];
            % Create title
            if str2num(Depths(y,:)) == 0
                line2 = 'Comparison of frequencies - outdoors';
            else
                line2 = ['Comparison of frequencies for an in-building depth of ', int2str(str2num(Depths(y,:))), ' metres'];
            end
            titleName = {['Coverage - ', sampleArea, ' - Minimum datarate ', int2str(sp.gBitRate), ' Mbps - 2x', bandwidth(k,:), ' MHz'],...
                         line2,...
                         fileName};
            title(titleName,'FontWeight','bold');

            % Create legend
            legend1 = legend(axes1,'show');
            set(legend1,'Location','SouthEast');

            % Save fig file
            fileName = ['/Coverage_', sampleArea, '_', Depths(y,:), 'm_', int2str(sp.gBitRate), 'Mbps_L', int2str(100*networkLoading(j)), '_', bandwidth(k,:), 'MHz_', timeStamp, '.fig'];
            saveas(gcf,[resultsFolderName, fileName]);

            % Save emf file (for import into MS Word
            fileName = ['/Coverage_', sampleArea, '_', Depths(y,:), 'm_', int2str(sp.gBitRate), 'Mbps_L', int2str(100*networkLoading(j)), '_', bandwidth(k,:), 'MHz_', timeStamp];
            print('-dmeta', [resultsFolderName, fileName])
        end
    end
end
