%% SCRIPT graphsSingleLoadingAllDepths
%
% Script to generate single user throughput graphs based on all depths 
%

% Martin Fenton - Version 1.0 03/01/12

% Check if timestamp exists, if not create timestampe from todays date and current time
if exist('timeStamp', 'var') == 0
    timeStamp = datestr(now,30);
end

% Create results folder
resultsFolderName = ['.\Results\', timeStamp(1:8), '\SingleLoading'];
[~,~,~] = mkdir(resultsFolderName);

% Create plots
% for y = 1:size(Depths, 1) % Loop through each BPL depth
    for k = 1:size(bandwidth,1)
        for i = 1:size(networkSize,1)
            for j = 1:length(networkLoading)

                % Close all current figures
                close all;
                figureName = ['Speed ', timeStamp];

                % Ensure root units are pixels and get the size of the screen
                set(0,'Units','pixels') 
                scnsize = get(0,'ScreenSize');

                % Create figure
                fig1 = figure('Name',figureName,...
                              'InvertHardcopy','off',...
                              'Color',[1 1 1]);

                % Set figure dimentions and centre on screen
                borders = get(fig1,'OuterPosition') - get(fig1,'Position');
                figWidth = 900;
                figHeight = 600;
                position = [scnsize(3)/2 + borders(1) - figWidth/2,...
                            scnsize(4)/2 + borders(2) - figHeight/2,...
                            figWidth + borders(3),...
                            figHeight + borders(4)];
                set(fig1,'OuterPosition',position);

                % Create axes
                axes1 = axes('Parent',fig1,'YGrid','on','XGrid','on','FontWeight','bold');
                % Uncomment the following line to preserve the X-limits of the axes
                % xlim(axes1,[0 100]);
                % Uncomment the following line to preserve the Y-limits of the axes
                ylim(axes1,[0 60]);
                % Uncomment the following line to preserve the Z-limits of the axes
                % zlim(axes1,[-1 1]);
                box(axes1,'on');
                hold(axes1,'all');

                % Create xlabel
                xlabel('Location (percentile)','FontWeight','bold');

                % Create ylabel
                ylabel('Single-user throughput (Mbps)','FontWeight','bold');

                Freq = length(Frequency);
                for z = 1:Freq

                    switch z
                        case 1
                            Colour = [1 0 0];
                        case 2
                            Colour = [0 0 1];
                        case 3
                            Colour = [0 0.5 0];
                        case 4
                            Colour = [1 0.5 0];
                        case 5
                            Colour = [1 1 0];
                        case 6
                            Colour = [1 0 1];
                        otherwise
                            Colour = [0 0 0];
                    end
                    
                    for m = 1:2     % 1 = best case, 2 = worst case

                        if BPRising(m) == -1   
                            outputName = 'MZ'; % [Depths(y,:), 'MZ'];
                        else
                            outputName = ['M', int2str(BPRising(m))]; % [Depths(y,:), 'M', int2str(BPRising(m))];
                        end

                        if m == 1
                            lineStyle = '-';
                            sName = 'Min var';
                        else
                            lineStyle = '--';
                            sName = 'Max var';
                        end

                        tempData(:,1) = eval(['TP_', outputName, '_M', int2str(m), '_', networkSize(i,:), '_', bandwidth(k,:), 'MHz(:,',int2str(z),',',int2str(j),')']);
                        tempData(:,2) = eval(['TP_', outputName, '_M', int2str(m), '_', networkSize(i,:), '_', bandwidth(k,:), 'MHz(:,',int2str(Freq+1),',',int2str(j),')']);
                        tempData(:,3) = eval(['TP_', outputName, '_M', int2str(m), '_', networkSize(i,:), '_', bandwidth(k,:), 'MHz(:,',int2str(Freq+2),',',int2str(j),')']);
                        clear Data;

                        if ~exist('Clutter','var') || strcmp(Clutter, 'All')
                            Clutter = 'All';
                            clut = 8;                       
                        elseif strcmp(Clutter,'Urban')
                            clut = [6, 7];
                        elseif strcmp(Clutter,'Suburban')
                            clut = 4;
                        else
                            clut = [1, 2, 3, 5];
                        end
                            
                        if clut == 8
                            Data = tempData(:,1:2);
                        else
                            Data = [0, 0];
                            for x = 1:length(clut)
                                index = tempData(:,3) == clut(x);
                                Data = [Data; tempData(index,1:2)];
                            end
                        end
                        Data = sortrows(Data,-1);
                        Data(:,2) = 100 * cumsum(Data(:,2)) / sum(Data(:,2));
                        seriesName = [bandwidth(k,:), 'MHz@', int2str(Frequency(z)), 'MHz, ', int2str(100*networkLoading(j)), '% loaded, ', sName];
                        plot(Data(:,2),Data(:,1),...
                             'Parent',axes1,...
                             'LineWidth',2,...
                             'LineStyle',lineStyle,...
                             'Color',Colour,...
                             'DisplayName',seriesName);

                    end
                end
                     
                fileName = ['Speed-', sampleArea, '-', Clutter, '-S', networkSize(i,:), '-L', int2str(100*networkLoading(j)), '-', bandwidth(k,:), 'MHz-', timeStamp];
                % Create title
                titleName = {['Single-user throughput as a function of location - ', sampleArea, ' - ', int2str(str2num(networkSize(i,:))), ' sites'],...
                             fileName};
                title(titleName,'FontWeight','bold');
        
                % Create legend
                legend(axes1,'show');

                % Save fig file
                fileName = ['/Speed_', sampleArea, '_', Clutter, '_S', networkSize(i,:), '_L', int2str(100*networkLoading(j)), '_', bandwidth(k,:), 'MHz_', timeStamp, '.fig'];
                saveas(gcf,[resultsFolderName, fileName]);

                % Save emf file (for import into MS Word
                fileName = ['/Speed_', sampleArea, '_', Clutter, '_S', networkSize(i,:), '_L', int2str(100*networkLoading(j)), '_', bandwidth(k,:), 'MHz_', timeStamp];
                print('-dmeta', [resultsFolderName, fileName])
            end
        end
    end
% end
