%% SCRIPT testCoverageAllDepths
%
% Script to calculate coverage based on all depths 
%

% Martin Fenton - Version 1.0 03/01/12
      
networkSize = networkSizes; 
bandwidth = ['05'; '10'; '15'; '20'];

SINR_min = [-10, -5];
tpMapping = ['1xMAP36.942(SINR-0dB)'; '1xMAP36.942(SINR-0dB)'];
BPRising = [-1, 2]; % Set best and worst case BPL dependancy with frequency
numSites = str2num(networkSize);

%% Set up structure containing throughput controls for throughput calculations and speed graphs
sp = struct('LoadingOwnCell', mc2.LoadingOwnCell,...
            'SINR_min', SINR_min(1),...
            'MIMO', mc2.MIMOMode,...
            'Mapping', tpMapping(1,:),...
            'gBitRate', 1);

sp.gBitRate = 1; % Minimum guaranteed bitrate (Mbps)       
            
for m = 1:2

    sp.Mapping = tpMapping(m,:);
    sp.SINR_min = SINR_min(m);

    if BPRising(m) == -1   
        outputName = 'MZ';
    else
        outputName = ['M', int2str(BPRising(m))];
    end

    for i = 1:size(bandwidth,1)
        for j = 1:size(networkSize,1)
            tempTP = eval(['SINR2TP(SINR_', outputName, '_', networkSize(j,:), ', ', bandwidth(i,:),', sp);']);
            for k = 1:length(networkLoading)
                for n = 1:length(Frequency)
                    [~, Index] = min(tempTP(:,3*(n-1)+1,k));
                    eval(['Cov_', outputName, '_M', int2str(m), '_', bandwidth(i,:), 'MHz(j,n,k) = tempTP(Index,3*(n-1)+2,k);']);
                end
            end
        end
    end

end
    

%% Create the timestamp based on the current date and time
timeStamp = datestr(now,30);

%% Create a results folder with datestamp equal to the current date
resultsFolderName = ['.\Results\', timeStamp(1:8), '\Coverage_', int2str(sp.gBitRate), 'Mbps'];
[~,~,~] = mkdir(resultsFolderName);

%% Save Coverage data
save([resultsFolderName, '/Cov_', int2str(sp.gBitRate), 'Mbps_', timeStamp], 'Frequency', 'networkLoading', 'networkSize', 'Depths', 'BPRising', 'bandwidth', 'SINR_min', 'tpMapping', 'sp', 'Cov*');

%% Create graphs - Coverage    
GraphsCoverageAllDepths;