%% SCRIPT testThroughputAllDepths
%
% Script to calculate single-user throughputs based on all depths 
%

% Martin Fenton - Version 1.0 03/01/12

%% Create the timestamp based on the current date and time
timeStamp = datestr(now,30);

%% Create a results folder with datestamp equal to the current date
resultsFolderName = ['.\Results\', timeStamp(1:8)];
[~,~,~] = mkdir(resultsFolderName);

%% Set up main parameters to control the throughput scenarios         
networkSize = networkSizes;
bandwidth = ['05'; '10'; '15'; '20'];
SINR_min = [-10, -5];
tpMapping = ['1xMAP36.942(SINR-0dB)'; '1xMAP36.942(SINR-0dB)']; % ['2xMAP36.942(SINR-3dB)'; '1xMAP36.942(SINR-0dB)'];
BPRising = [-1, 2]; % Set best and worst case BPL dependancy with frequency
numSites = str2num(networkSize);

%% Set up structure containing throughput controls for throughput calculations and speed graphs
sp = struct('LoadingOwnCell', mc2.LoadingOwnCell,...
            'SINR_min', SINR_min(1),...
            'MIMO', mc2.MIMOMode,...
            'Mapping', tpMapping(1,:),...
            'gBitRate', 0.000);

%% Generate Throughput data and speed and coverage graphs for best and worst case of throughput mapping and min SINR cut-off
    
    for m = 1:2

        sp.Mapping = tpMapping(m,:);
        sp.SINR_min = SINR_min(m);

        if BPRising(m) == -1   
            outputName = 'MZ'; % [Depths(y,:), 'MZ'];
        else
            outputName = ['M', int2str(BPRising(m))]; % [Depths(y,:), 'M', int2str(BPRising(m))];
        end

        % Calculate Throughputs
        for i = 1:size(networkSize,1)
            for j = 1:size(bandwidth,1)
                eval(['TP_', outputName, '_M', int2str(m), '_' , networkSize(i,:), '_', bandwidth(j,:), 'MHz = SINR2TP(SINR_', outputName, '_', networkSize(i,:), ', ', bandwidth(j,:),', sp);']);
            end
        end
    end

%% Save TP distributions
save([resultsFolderName, '\TP_', sampleArea, '_', timeStamp], 'Frequency', 'networkLoading', 'networkSize', 'Depths', 'BPRising', 'bandwidth', 'SINR_min', 'tpMapping', 'sp', 'TP*');

%% Create graphs - Throughput Single loading
Clutter = 'All';  % All clutter types
graphsSingleLoadingAllDepths; % Generate graph with best and worst case lines - All clutter types