%% SCRIPT upSampleSites
%
% Script to generate an equivalent national network size of [20000] sites within the test area. It takes as its
% input the co-ordinates and heights of the base stations from a smaller seed network within the test area and
% then places a new site at the geometric centroid of triangles containing the highest number of delivery
% points, i.e. the new sites are first placed in what approximates the highest population areas. 
%

% Sanya Osisanya - Version 1.0 09/11/11

%% Detect if Parallel computing toolbox is installed and if so select the
% parallel version of the Simulation function
tic
v = ver('distcomp');
if str2num(v.Version) >= 5.3    % Parallel code written using version 5.1 of the parallel computing toolbox (assumes backwards compatibility for future releases)
    Parallel = 1;
    if matlabpool('size') > 0
        matlabpool close        % If a pool of worker is already open, close it
    end
    matlabpool open local 4     % Run code on a pool of 3 lab workers in parallel (if duel core set to 2)
else
    Parallel = 0;
end

targetNetworkSize = 20000;
realNetworkSize = 8967;

realSites = size(bs,1);
synthSites = ceil(realSites * targetNetworkSize / realNetworkSize) - realSites;

del = delaunay(bs(:,1),bs(:,2));                   %bs = actual O2 network paarameters...get indices of BS that form triangles
all=[];bank=[0 0];dp=zeros(size(del,1),1);
triplot(del,bs(:,1),bs(:,2)); hold on

CentroidDataE = CentroidData(:,1);              % Slice to speed up the parfor/for loop
CentroidDataN = CentroidData(:,2);              % Slice to speed up the parfor/for loop
CentroidDataD = CentroidData(:,4);              % Slice to speed up the parfor/for loop

for ct=1:(size(del,1))
    bank=[0 0];
    
    coord(1,:)=bs(del(ct,1),1:2);                       %get cordinates of the vertices that form the triangles
    coord(2,:)=bs(del(ct,2),1:2);
    coord(3,:)=bs(del(ct,3),1:2);
    coord(4,:)=bs(del(ct,1),1:2);                       %close the polygon
    
    in=inpolygon(CentroidDataE,CentroidDataN,coord(:,1),coord(:,2)); %get centroids/delivery points within polygon formed in ct   

    tempDeliveryData = CentroidDataD(in);      % Create tem variable just containing centroids/delivery points with the triangle
    
    dp(ct)=sum(tempDeliveryData);      % Sum the delivery addresses within the triangle
    coord=[];
    
end


[DP ind]=sort(dp,'descend');                               %sort the number of delivery points in each triangle
% new=[];                                                    %hold co-ordinates of new sites

if synthSites > size(del,1)         % Check if there are enough triangles to reach the intended site count
    y = size(del,1);
else
    y = synthSites;
end

cd = zeros(y,3);
new = zeros(y,4);

for x=1:y                                        %adj is the number of additional sites required for equivalent site count of  20000 synthetic network size
    cd(x,:)=del(ind(x),:);                                           %fetch the points or indices representing the vertices of the triangle 
    E=(bs(cd(x,1),1)+bs(cd(x,2),1)+bs(cd(x,3),1))/3;       %eastings of new site
    N=(bs(cd(x,1),2)+bs(cd(x,2),2)+bs(cd(x,3),2))/3;       %northings of new site
    H=(bs(cd(x,1),3)+bs(cd(x,2),3)+bs(cd(x,3),3))/3;
    new(x,:)=[E N H 45];
end

Syn_network=[bs;new];
toc
